local metrics = require('metrics')

metrics.http_middleware.configure_default_collector('summary')

-- Simple router to make routing more clear.
local Router = {
    mt = {},
    global_prefix = '',
}

Router.mt.__index = Router.mt
setmetatable(Router.mt, {
    -- Dynamic function for http methods.
    --
    --     router:get(path, hanlder [, options])
    __index = function (_, method)
        return function(self, path, handler, options)
            options = options or {}
            options.path = self.prefix_value .. path
            options.method = method:upper()
            if rawget(self, 'middleware') then
                handler = self.middleware(handler)
            end
            handler = metrics.http_middleware.v1(handler)
            self.httpd:route(options, handler)
        end
    end
})

function Router:new(httpd, options)
    return setmetatable({
        httpd = httpd,
        middleware = options.middleware,
        prefix_value = self.global_prefix .. (options.prefix or ''),
    }, self.mt)
end

-- Prefix all routes within block.
function Router.mt:prefix(prefix, fn)
    local old_value = self.prefix_value
    self.prefix_value = self.prefix_value .. prefix
    fn()
    self.prefix_value = old_value
end

return Router
