local cartridge = require('cartridge')
local registry = require('cartridge.service-registry')
local metrics_vars = require('cartridge.vars').new('metrics_vars')
local log = require('log')

local function metrics_role_found()
    return registry.get('metrics') ~= nil
end

local function set_default_labels(uuid, alias)
    local default_labels = metrics_vars.default_labels or {}
    default_labels.replicaset_uuid = uuid
    default_labels.replicaset_alias = alias

    if not metrics_role_found() then
        if uuid or alias then
            log.warn('No metrics role found.')
        end
    else
        local metrics = registry.get('metrics')
        metrics.set_default_labels(default_labels)
    end
end

local function add_replicaset_labels()
    local replicaset_uuid = box.info.cluster.uuid
    local replicaset_alias = cartridge.admin_get_replicasets(replicaset_uuid)[1].alias
    set_default_labels(replicaset_uuid, replicaset_alias)
end

local function remove_replicaset_labels()
    set_default_labels(nil, nil)
end

return {
    add = add_replicaset_labels,
    remove = remove_replicaset_labels,
    metrics_role_found = metrics_role_found
}
